@@ -37,16 +37,15 @@ class QmlAppletScript;
 class QSignalMapper;
 class QSizeF;
 
-class ConfigView;
-
-namespace KDeclarative {
-    class ConfigPropertyMap;
-    class QmlObject;
+namespace KDeclarative
+{
+class ConfigPropertyMap;
+class QmlObject;
 }
 
 namespace Plasma
 {
-    class ConfigLoader;
+class ConfigLoader;
 } // namespace Plasma
 
 class AppletInterface : public PlasmaQuick::AppletQuickItem
@@ -62,6 +61,11 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      */
     Q_PROPERTY(int apiVersion READ apiVersion CONSTANT)
 
+    /**
+     * Plugin name of the plasmoid
+     */
+    Q_PROPERTY(QString pluginName READ pluginName CONSTANT)
+
     /**
      * User friendly title for the plasmoid: it's the localized applet name by default
      */
@@ -107,7 +111,7 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
     /**
      * Configuration object: each config key will be a writable property of this object. property bindings work.
      */
-    Q_PROPERTY(QObject* configuration READ configuration CONSTANT)
+    Q_PROPERTY(QObject *configuration READ configuration CONSTANT)
 
     /**
      * When true the plasmoid is busy. The containment may graphically indicate that drawing for instance a spinner busy widget over it
@@ -135,10 +139,14 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
     Q_PROPERTY(Plasma::Types::ItemStatus status READ status WRITE setStatus NOTIFY statusChanged)
 
     /**
-     * Sets the associated application of this plasmoid, if the plasmoid is representing the "compact" view for some application or for some document type. 
-     * TODO: a way to set associated application urls.
+     * Sets the associated application of this plasmoid, if the plasmoid is representing the "compact" view for some application or for some document type.
      */
-    Q_PROPERTY(QString associatedApplication WRITE setAssociatedApplication READ associatedApplication)
+    Q_PROPERTY(QString associatedApplication WRITE setAssociatedApplication READ associatedApplication NOTIFY associatedApplicationChanged)
+
+    /**
+     * Sets the associated application of this plasmoid, if the plasmoid is representing the "compact" view for some application or for some document type.
+     */
+    Q_PROPERTY(QList<QUrl> associatedApplicationUrls WRITE setAssociatedApplicationUrls READ associatedApplicationUrls NOTIFY associatedApplicationUrlsChanged)
 
     // TODO: This was moved up from ContainmentInterface because it is required by the
     // Task Manager applet (for "Show only tasks from this screen") and no Qt API exposes
@@ -146,6 +154,12 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
     // would be preferrable if found.
     Q_PROPERTY(int screen READ screen NOTIFY screenChanged)
 
+    /**
+     * Provides access to the geometry of the applet is in.
+     * Can be useful to figure out what's the absolute position of the applet.
+     */
+    Q_PROPERTY(QRect screenGeometry READ screenGeometry NOTIFY screenChanged)
+
     /**
      * Whether the dialog should be hidden when the dialog loses focus.
      *
@@ -153,16 +167,24 @@ class AppletInterface : public PlasmaQuick::AppletQuickItem
      **/
     Q_PROPERTY(bool hideOnWindowDeactivate READ hideOnWindowDeactivate WRITE setHideOnWindowDeactivate NOTIFY hideOnWindowDeactivateChanged)
 
+    /**
+     * The global shortcut to activate the plasmoid
+     *
+     * This is typically only used by the default configuration module
+     *
+     */
+    Q_PROPERTY(QKeySequence globalShortcut READ globalShortcut WRITE setGlobalShortcut NOTIFY globalShortcutChanged)
 
 public:
-    AppletInterface(DeclarativeAppletScript *script, QQuickItem *parent = 0);
+    AppletInterface(DeclarativeAppletScript *script, const QVariantList &args = QVariantList(), QQuickItem *parent = 0);
+    AppletInterface(Plasma::Applet *applet, const QVariantList &args = QVariantList(), QQuickItem *parent = 0);
     ~AppletInterface();
 
 //API not intended for the QML part
 
     DeclarativeAppletScript *appletScript() const;
 
-    QList<QAction*> contextualActions() const;
+    QList<QAction *> contextualActions() const;
 
     void executeAction(const QString &name);
 
@@ -176,6 +198,14 @@ public:
     Q_INVOKABLE void setConfigurationRequired(bool needsConfiguring, const QString &reason = QString());
 
     Q_INVOKABLE void setActionSeparator(const QString &name);
+    /**
+     * Add an action to the Plasmoid contextual menu.
+     * When the action is triggered a function called action_<name> will be called, if there is no function with that name actionTriggered(name) will be called instead.
+     * @param: action name
+     * @text: user visible displayed text
+     * @icon: user visible optional displayed icon
+     * @shortcut: shortcut to trigger this action
+     */
     Q_INVOKABLE void setAction(const QString &name, const QString &text,
                                const QString &icon = QString(), const QString &shortcut = QString());
 
@@ -216,6 +246,8 @@ public:
     }
 
 //PROPERTY ACCESSORS-------------------------------------------------------------------
+    QString pluginName() const;
+
     QString icon() const;
     void setIcon(const QString &icon);
 
@@ -236,7 +268,7 @@ public:
 
     QString currentActivity() const;
 
-    QObject* configuration() const;
+    QObject *configuration() const;
 
     bool isBusy() const;
     void setBusy(bool busy);
@@ -247,10 +279,14 @@ public:
     void setAssociatedApplication(const QString &string);
     QString associatedApplication() const;
 
+    void setAssociatedApplicationUrls(const QList<QUrl> &urls);
+    QList<QUrl> associatedApplicationUrls() const;
+
     void setStatus(const Plasma::Types::ItemStatus &status);
     Plasma::Types::ItemStatus status() const;
 
     int screen() const;
+    QRect screenGeometry() const;
 
     bool immutable() const;
     bool userConfiguring() const;
@@ -259,6 +295,9 @@ public:
     bool hideOnWindowDeactivate() const;
     void setHideOnWindowDeactivate(bool hide);
 
+    QKeySequence globalShortcut() const;
+    void setGlobalShortcut(const QKeySequence &keySequence);
+
 Q_SIGNALS:
     /**
      * somebody else, usually the containment sent some data to the applet
@@ -269,6 +308,18 @@ Q_SIGNALS:
 
     void configNeedsSaving();
 
+    /**
+     * Emitted when the applet's activation action is triggered
+     */
+    void activated();
+
+    /**
+     * Emitted just before the contextual actions are about to show
+     * For instance just before the context menu containing the actions
+     * added with setAction() is shown
+     */
+    void contextualActionsAboutToShow();
+
 //PROPERTY change notifiers--------------
     void iconChanged();
     void titleChanged();
@@ -283,12 +334,18 @@ Q_SIGNALS:
     void busyChanged();
     void screenChanged();
     void hideOnWindowDeactivateChanged();
+    void associatedApplicationChanged();
+    void associatedApplicationUrlsChanged();
 
     void userConfiguringChanged();
+    void globalShortcutChanged();
 
 protected Q_SLOTS:
     virtual void init();
 
+protected:
+    bool eventFilter(QObject *watched, QEvent *event);
+
 private:
 
     QStringList m_actions;
@@ -299,9 +356,9 @@ private:
 
 //UI-specific members ------------------
 
-
     QString m_toolTipMainText;
     QString m_toolTipSubText;
+    QVariantList m_args;
     Plasma::Types::BackgroundHints m_backgroundHints;
     bool m_busy : 1;
     bool m_hideOnDeactivate : 1;
